diff libtomcrypt/src/pk/rsa/rsa_import.c @ 1435:f849a5ca2efc

update to libtomcrypt 1.17 (with Dropbear changes)
author Matt Johnston <matt@ucc.asn.au>
date Sat, 24 Jun 2017 17:50:50 +0800
parents 0cbe8f6dbf9e
children 6dba84798cd5
line wrap: on
line diff
--- a/libtomcrypt/src/pk/rsa/rsa_import.c	Sat Jun 24 11:53:32 2017 +0800
+++ b/libtomcrypt/src/pk/rsa/rsa_import.c	Sat Jun 24 17:50:50 2017 +0800
@@ -6,19 +6,19 @@
  * The library is free for all purposes without any express
  * guarantee it works.
  *
- * Tom St Denis, [email protected], http://libtomcrypt.com
+ * Tom St Denis, [email protected], http://libtom.org
  */
 #include "tomcrypt.h"
 
 /**
   @file rsa_import.c
-  Import a PKCS RSA key, Tom St Denis
+  Import a LTC_PKCS RSA key, Tom St Denis
 */  
 
-#ifdef MRSA
+#ifdef LTC_MRSA
 
 /**
-  Import an RSAPublicKey or RSAPrivateKey [two-prime only, only support >= 1024-bit keys, defined in PKCS #1 v2.1]
+  Import an RSAPublicKey or RSAPrivateKey [two-prime only, only support >= 1024-bit keys, defined in LTC_PKCS #1 v2.1]
   @param in      The packet to import from
   @param inlen   It's length (octets)
   @param key     [out] Destination for newly imported key
@@ -87,7 +87,7 @@
    }
    XFREE(tmpbuf);
 
    /* not SSL public key, try to match against PKCS #1 standards */
    if ((err = der_decode_sequence_multi(in, inlen, 
                                   LTC_ASN1_INTEGER, 1UL, key->N, 
                                   LTC_ASN1_EOL,     0UL, NULL)) != CRYPT_OK) {
@@ -135,9 +135,9 @@
    return err;
 }
 
-#endif /* MRSA */
+#endif /* LTC_MRSA */
 
 
-/* $Source: /cvs/libtom/libtomcrypt/src/pk/rsa/rsa_import.c,v $ */
-/* $Revision: 1.21 $ */
-/* $Date: 2006/12/04 22:23:27 $ */
+/* $Source$ */
+/* $Revision$ */
+/* $Date$ */
@@ -87,7 +87,7 @@
    XFREE(tmpbuf);
 
-   /* not SSL public key, try to match against PKCS #1 standards */
+   /* not SSL public key, try to match against LTC_PKCS #1 standards */
    if ((err = der_decode_sequence_multi(in, inlen, 
                                   LTC_ASN1_INTEGER, 1UL, key->N, 